@@ -1,8 +1,9 @@
 def devbio_napari_viewer():
     import napari
     from qtpy.QtCore import QTimer
+    from devbio_napari import __version__ as version
 
-    viewer = napari.Viewer(title="devbio_napari - napari")
+    viewer = napari.Viewer(title="devbio-napari" )
 
     #viewer.window.add_plugin_dock_widget("napari-mouse-controls", "Mouse Controls")
 
